@@ -1,13 +1,13 @@
 .do_by_layer_table <- function(dataset, input.location){
   
-  df <- table(dataset$layer, dataset$location_mode)
+  df <- table(dataset$layer, dataset$location_mode, useNA = "ifany")
   
   if(nrow(df) == 0) return()
   
   if("show.uncertainty" %in% input.location){
     dataset$fuzzy.sum <- factor(dataset$fuzzy.sum, levels = c(0, 1, 2, 3), 
            labels = c("exact", "linear", "planar", "volume"))
-    df <- table(dataset$layer, dataset$fuzzy.sum)
+    df <- table(dataset$layer, dataset$fuzzy.sum, useNA = "ifany")
   }
   
   if(ncol(df) > 1){
@@ -25,6 +25,7 @@
   }
   
   colnames(df) <- sapply(colnames(df), .term_switcher)
+  rownames(df)[is.na(rownames(df))] <- "NA"
   rownames(df)[nrow(df)] <- .term_switcher("total")
   data.frame(df)
 }
