@@ -4,12 +4,13 @@
   square.labels <- levels(square.list)
   
   if(max.nr.of.squares == length(square.labels) ){
-    squares <- square.labels
+    squares.print <- square.labels
   }  else {
     message(paste0(max.nr.of.squares, " ", axes, " squares, but ",
                    length(square.labels), " labels provided: ", 
                    paste0(square.labels, collapse = ", "), ".\n"))
-    squares <- "" # if the nr of square labels is insufficient, do not display the labels
+    squares.print <- NULL # "" # if the nr of square labels is insufficient, do not display the labels
   }
-  squares
+  list("squares.print" = squares.print,
+       "squares.save" = square.labels)
 }
\ No newline at end of file
